@@ -4,7 +4,6 @@ import (
 	"bufio"
 	"bytes"
 	"io"
-	"path/filepath"
 	"sync"
 	"testing"
 
@@ -13,6 +12,7 @@ import (
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/exectest"
+	ffs "github.com/helmfile/helmfile/pkg/filesystem"
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/testhelper"
 )
@@ -1352,8 +1352,7 @@ changing working directory back to "/path/to"
 
 				app := appWithFs(&App{
 					OverrideHelmBinary:  DefaultHelmBinary,
-					glob:                filepath.Glob,
-					abs:                 filepath.Abs,
+					fs:                  ffs.DefaultFileSystem(),
 					OverrideKubeContext: overrideKubeContext,
 					Env:                 "default",
 					Logger:              logger,
