@@ -8,13 +8,14 @@ import (
 	"path"
 	"path/filepath"
 	"reflect"
+	"regexp"
 	"testing"
 
-	"github.com/google/go-cmp/cmp"
-	"github.com/helmfile/helmfile/pkg/envvar"
-
 	"github.com/Masterminds/semver/v3"
+	"github.com/google/go-cmp/cmp"
 	"go.uber.org/zap"
+
+	"github.com/helmfile/helmfile/pkg/envvar"
 )
 
 // Mocking the command-line runner
@@ -32,6 +33,7 @@ func (mock *mockRunner) Execute(cmd string, args []string, env map[string]string
 	return mock.output, mock.err
 }
 
+// nolint: golint
 func MockExecer(logger *zap.SugaredLogger, kubeContext string) *execer {
 	execer := New("helm", logger, kubeContext, &mockRunner{})
 	return execer
@@ -362,10 +364,7 @@ func Test_DecryptSecret(t *testing.T) {
 
 	_, err := helm.DecryptSecret(HelmContext{}, "secretName")
 	if err != nil {
-		if _, ok := err.(*os.PathError); ok {
-		} else {
-			t.Errorf("Error: %v", err)
-		}
+		t.Errorf("Error: %v", err)
 	}
 	cwd, err := filepath.Abs(".")
 	if err != nil {
@@ -376,10 +375,12 @@ func Test_DecryptSecret(t *testing.T) {
 
 	expected := fmt.Sprintf(`Preparing to decrypt secret %v/secretName
 Decrypting secret %s/secretName
-exec: helm --kube-context dev secrets dec %s/secretName
+exec: helm --kube-context dev secrets view %s/secretName
+Decrypted %s/secretName into %s
 Preparing to decrypt secret %s/secretName
 Found secret in cache %s/secretName
-`, cwd, cwd, cwd, cwd, cwd)
+Decrypted %s/secretName into %s
+`, cwd, cwd, cwd, cwd, tmpFilePath, cwd, cwd, cwd, tmpFilePath)
 	if err != nil {
 		if _, ok := err.(*os.PathError); ok {
 		} else {
@@ -402,14 +403,24 @@ func Test_DecryptSecretWithGotmpl(t *testing.T) {
 	}
 
 	secretName := "secretName.yaml.gotmpl"
-	_, decryptErr := helm.DecryptSecret(HelmContext{}, secretName)
+	_, err := helm.DecryptSecret(HelmContext{}, secretName)
+	if err != nil {
+		t.Errorf("Error: %v", err)
+	}
 	cwd, err := filepath.Abs(".")
 	if err != nil {
 		t.Errorf("Error: %v", err)
 	}
 
-	expected := fmt.Sprintf(`%s/%s.yaml.dec`, cwd, secretName)
-	if d := cmp.Diff(expected, decryptErr.(*os.PathError).Path); d != "" {
+	expected := fmt.Sprintf(`Preparing to decrypt secret %v/secretName.yaml.gotmpl
+Decrypting secret %s/secretName.yaml.gotmpl
+exec: helm --kube-context dev secrets view %s/secretName.yaml.gotmpl
+Decrypted %s/secretName.yaml.gotmpl into %s
+`, cwd, cwd, cwd, cwd, tmpFilePath)
+	if err != nil {
+		t.Errorf("Error: %v", err)
+	}
+	if d := cmp.Diff(expected, buffer.String()); d != "" {
 		t.Errorf("helmexec.DecryptSecret(): want (-), got (+):\n%s", d)
 	}
 }
@@ -665,33 +676,117 @@ exec: helm --kube-context dev fetch https://example_user:example_password@repo.e
 func Test_ChartPull(t *testing.T) {
 	var buffer bytes.Buffer
 	logger := NewLogger(&buffer, "debug")
-	helm := MockExecer(logger, "dev")
-	err := helm.ChartPull("chart", "--version", "1.2.3", "--untar", "--untardir", "/tmp/dir")
-	expected := `Pulling chart
+	tests := []struct {
+		name        string
+		helmBin     string
+		helmVersion string
+		chartName   string
+		chartFlags  []string
+		listResult  string
+	}{
+		{
+			name:        "less then v3.7.0",
+			helmBin:     "helm",
+			helmVersion: "v3.6.0",
+			chartName:   "chart",
+			chartFlags:  []string{"--untar", "--untardir", "/tmp/dir"},
+			listResult: `Pulling chart
 Exporting chart
-exec: helm --kube-context dev chart pull chart --version 1.2.3 --untar --untardir /tmp/dir
-`
-	if err != nil {
-		t.Errorf("unexpected error: %v", err)
+exec: helm --kube-context dev chart pull chart --untar --untardir /tmp/dir
+`,
+		},
+		{
+			name:        "more then v3.7.0",
+			helmBin:     "helm",
+			helmVersion: "v3.9.0",
+			chartName:   "repo/helm-charts:0.14.0",
+			chartFlags:  []string{"--untardir", "/tmp/dir"},
+			listResult: `Pulling repo/helm-charts:0.14.0
+Exporting repo/helm-charts:0.14.0
+exec: helm --kube-context dev fetch oci://repo/helm-charts --version 0.14.0 --destination [\w/]+ --untardir /tmp/dir
+`,
+		},
 	}
-	if buffer.String() != expected {
-		t.Errorf("helmexec.ChartPull()\nactual = %v\nexpect = %v", buffer.String(), expected)
+	for i := range tests {
+		tt := tests[i]
+		t.Run(tt.name, func(t *testing.T) {
+			buffer.Reset()
+			helm := &execer{
+				helmBinary:  tt.helmBin,
+				version:     *semver.MustParse(tt.helmVersion),
+				logger:      logger,
+				kubeContext: "dev",
+				runner:      &mockRunner{},
+			}
+			err := helm.ChartPull(tt.chartName, tt.chartFlags...)
+			if err != nil {
+				t.Errorf("unexpected error: %v", err)
+			}
+			isMatch, _ := regexp.MatchString(tt.listResult, buffer.String())
+			if !isMatch {
+				t.Errorf("helmexec.ChartPull()\nactual = %v\nexpect = %v", buffer.String(), tt.listResult)
+			}
+		})
 	}
 }
 
 func Test_ChartExport(t *testing.T) {
 	var buffer bytes.Buffer
 	logger := NewLogger(&buffer, "debug")
-	helm := MockExecer(logger, "dev")
-	err := helm.ChartExport("chart", "--version", "1.2.3", "--untar", "--untardir", "/tmp/dir")
-	expected := `Exporting chart
-exec: helm --kube-context dev chart export chart --destination --version 1.2.3 --untar --untardir /tmp/dir
-`
-	if err != nil {
-		t.Errorf("unexpected error: %v", err)
+	tests := []struct {
+		name          string
+		helmBin       string
+		helmVersion   string
+		chartName     string
+		chartPath     string
+		chartFlags    []string
+		listResult    string
+		expectedError string
+	}{
+		{
+			name:        "",
+			helmBin:     "helm",
+			helmVersion: "v3.6.0",
+			chartName:   "chart",
+			chartPath:   "path1",
+			chartFlags:  []string{"--untar", "--untardir", "/tmp/dir"},
+			listResult: `Exporting chart
+exec: helm --kube-context dev chart export chart --destination path1 --untar --untardir /tmp/dir
+`,
+			expectedError: "",
+		},
+		{
+			name:        "",
+			helmBin:     "helm",
+			helmVersion: "v3.9.0",
+			chartName:   "repo/helm-charts:0.14.0",
+			chartPath:   "path1",
+			chartFlags:  []string{"--untardir", "/tmp/dir"},
+			listResult: `Exporting repo/helm-charts:0.14.0
+exec: helm --kube-context dev pull oci://repo/helm-charts --version 0.14.0 --untar --destination path1 --untardir /tmp/dir
+`,
+			expectedError: "",
+		},
 	}
-	if buffer.String() != expected {
-		t.Errorf("helmexec.ChartExport()\nactual = %v\nexpect = %v", buffer.String(), expected)
+	for i := range tests {
+		tt := tests[i]
+		t.Run(tt.name, func(t *testing.T) {
+			buffer.Reset()
+			helm := &execer{
+				helmBinary:  tt.helmBin,
+				version:     *semver.MustParse(tt.helmVersion),
+				logger:      logger,
+				kubeContext: "dev",
+				runner:      &mockRunner{},
+			}
+			err := helm.ChartExport(tt.chartName, tt.chartPath, tt.chartFlags...)
+			if err != nil {
+				t.Errorf("unexpected error: %v", err)
+			}
+			if buffer.String() != tt.listResult {
+				t.Errorf("helmexec.ChartExport()\nactual = %v\nexpect = %v", buffer.String(), tt.listResult)
+			}
+		})
 	}
 }
 
@@ -807,14 +902,14 @@ func Test_GetVersion(t *testing.T) {
 	helm := New("helm", NewLogger(os.Stdout, "info"), "dev", &helm2Runner)
 	ver := helm.GetVersion()
 	if ver.Major != 2 || ver.Minor != 16 || ver.Patch != 1 {
-		t.Error(fmt.Sprintf("helmexec.GetVersion - did not detect correct Helm2 version; it was: %+v", ver))
+		t.Errorf("helmexec.GetVersion - did not detect correct Helm2 version; it was: %+v", ver)
 	}
 
 	helm3Runner := mockRunner{output: []byte("v3.2.4+ge29ce2a\n")}
 	helm = New("helm", NewLogger(os.Stdout, "info"), "dev", &helm3Runner)
 	ver = helm.GetVersion()
 	if ver.Major != 3 || ver.Minor != 2 || ver.Patch != 4 {
-		t.Error(fmt.Sprintf("helmexec.GetVersion - did not detect correct Helm3 version; it was: %+v", ver))
+		t.Errorf("helmexec.GetVersion - did not detect correct Helm3 version; it was: %+v", ver)
 	}
 }
 
@@ -833,3 +928,42 @@ func Test_IsVersionAtLeast(t *testing.T) {
 		t.Error("helmexec.IsVersionAtLeast - 2.16.1 is atleast 3.2")
 	}
 }
+
+func Test_resolveOciChart(t *testing.T) {
+	tests := []struct {
+		name        string
+		chartPath   string
+		ociChartURL string
+		ociChartTag string
+	}{
+		{
+			name:        "normal",
+			chartPath:   "chart/nginx:v1",
+			ociChartURL: "oci://chart/nginx",
+			ociChartTag: "v1",
+		},
+		{
+			name:        "contains the port",
+			chartPath:   "chart:5000/nginx:v1",
+			ociChartURL: "oci://chart:5000/nginx",
+			ociChartTag: "v1",
+		},
+		{
+			name:        "no tag",
+			chartPath:   "chart:5000/nginx",
+			ociChartURL: "oci://chart:5000/nginx",
+			ociChartTag: "",
+		},
+	}
+	for i := range tests {
+		tt := tests[i]
+		t.Run(tt.name, func(t *testing.T) {
+			url, tag := resolveOciChart(tt.chartPath)
+			if tt.ociChartURL != url || tt.ociChartTag != tag {
+				actual := fmt.Sprintf("ociChartURL->%s  ociChartTag->%s", url, tag)
+				expected := fmt.Sprintf("ociChartURL->%s ociChartTag->%s", tt.ociChartURL, tt.ociChartTag)
+				t.Errorf("resolveOciChart()\nactual = %v\nexpect = %v", actual, expected)
+			}
+		})
+	}
+}
