@@ -35,6 +35,6 @@ func CaptureStdout(f func()) string {
 	}()
 	wg.Wait()
 	f()
-	writer.Close()
+	_ = writer.Close()
 	return <-out
 }
